==> sihnpy-0.1.0.tar.gz: sihnpy-0.1.0/LICENSE.md <==
# License

MIT License

Copyright (c) 2022, Frédéric St-Onge

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

HOWEVER, any party using the data from the PREVENT-AD cohort included within
the Software agree to respect the conditions that all users downloading the
data agree to which are:

PUBLICATION AGREEMENT
- If I publish abstracts using data from PREVENT-AD, I agree to the following:
    "I will cite PREVENT-AD as the source of data in the abstract if space allows
- If I publish manuscripts using data from PREVENT-AD, I agree to the following:
    "I will state the source of data and cite the primary publication of PREVENT-AD 
    in the methods section of my manuscripts by including language similar to the 
    following: 'Data used in preparation of this article were obtained from the 
    Pre-symptomatic Evaluation of Novel or Experimental Treatments for Alzheimer's 
    Disease (PREVENT-AD) program. (Breitner et al., 2016)'.

COMMERCIALIZATION AGREEMENT
- I will not attempt to sell or claim intellectual property rights in the 
    PREVENT-AD dataset

PRIVACY AGREEMENT
- I will not attempt to re-identify or re-contact individual participants
- In particular, I will not link the data to other datasets if that could 
    lead to their re-identification

ETHICAL OVERSIGHT AGREEMENT
- I will obtain any required approvals for the use of the PREVENT-AD dataset

USE RESTRICTION AGREEMENT
- This open PREVENT-AD dataset must be used for ‘neurosciences research’ 
    as stipulated in the consent form.*

CONFIDENTIALITY AGREEMENT
- Sharing of this dataset must be done through this portal. Do not 
    redistribute the data yourself. Redirect potential users to this portal
    so they can register and agree to these terms.*

MONITORING AGREEMENT
- I will respond to requests from PREVENT-AD, if any. I will immediately 
    report to PREVENT-AD activity that breaches these terms.

Clauses with asterisks are copied integrally from the original data usage 
agreement. Users wishing to use the Prevent-AD data within the Software 
agree to use the data for educational purposes only. Users wishing to use
the Prevent-AD data for research purposes must register on the portal before
doing so: https://openpreventad.loris.ca/login/request-account/

==> sihnpy-0.2.0.tar.gz: sihnpy-0.2.0/LICENSE.md <==
# License

MIT License

Copyright (c) 2022, Frédéric St-Onge

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

HOWEVER, any party using the data from the PREVENT-AD cohort included within
the Software agree to respect the conditions that all users downloading the
data agree to which are:

PUBLICATION AGREEMENT
- If I publish abstracts using data from PREVENT-AD, I agree to the following:
    "I will cite PREVENT-AD as the source of data in the abstract if space allows
- If I publish manuscripts using data from PREVENT-AD, I agree to the following:
    "I will state the source of data and cite the primary publication of PREVENT-AD 
    in the methods section of my manuscripts by including language similar to the 
    following: 'Data used in preparation of this article were obtained from the 
    Pre-symptomatic Evaluation of Novel or Experimental Treatments for Alzheimer's 
    Disease (PREVENT-AD) program. (Breitner et al., 2016)'.

COMMERCIALIZATION AGREEMENT
- I will not attempt to sell or claim intellectual property rights in the 
    PREVENT-AD dataset

PRIVACY AGREEMENT
- I will not attempt to re-identify or re-contact individual participants
- In particular, I will not link the data to other datasets if that could 
    lead to their re-identification

ETHICAL OVERSIGHT AGREEMENT
- I will obtain any required approvals for the use of the PREVENT-AD dataset

USE RESTRICTION AGREEMENT
- This open PREVENT-AD dataset must be used for ‘neurosciences research’ 
    as stipulated in the consent form.*

CONFIDENTIALITY AGREEMENT
- Sharing of this dataset must be done through this portal. Do not 
    redistribute the data yourself. Redirect potential users to this portal
    so they can register and agree to these terms.*

MONITORING AGREEMENT
- I will respond to requests from PREVENT-AD, if any. I will immediately 
    report to PREVENT-AD activity that breaches these terms.

Clauses with asterisks are copied integrally from the original data usage 
agreement. Users wishing to use the Prevent-AD data within the Software 
agree to use the data for educational purposes only. Users wishing to use
the Prevent-AD data for research purposes must register on the portal before
doing so: [https://openpreventad.loris.ca/login/request-account/](https://openpreventad.loris.ca/login/request-account/)
